/*
*    Yerase's TNEF Stream Reader Library
*    Copyright (C) 2003  Randall E. Hand
*
*    This program is free software; you can redistribute it and/or modify
*    it under the terms of the GNU General Public License as published by
*    the Free Software Foundation; either version 2 of the License, or
*    (at your option) any later version.
*
*    This program is distributed in the hope that it will be useful,
*    but WITHOUT ANY WARRANTY; without even the implied warranty of
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*    GNU General Public License for more details.
*
*    You should have received a copy of the GNU General Public License
*    along with this program; if not, write to the Free Software
*    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*
*    You can contact me at randall.hand@gmail.com for questions or assistance
*/
#ifndef _TNEF_ERRORS_
#define _TNEF_ERRORS_


#define YTNEF_CANNOT_INIT_DATA -1
#define YTNEF_NOT_TNEF_STREAM  -2
#define YTNEF_ERROR_READING_DATA -3
#define YTNEF_NO_KEY -4
#define YTNEF_BAD_CHECKSUM -5
#define YTNEF_ERROR_IN_HANDLER -6
#define YTNEF_UNKNOWN_PROPERTY -7
#define YTNEF_INCORRECT_SETUP -8


#endif

